@@ -2,19 +2,34 @@
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-#include <QDebug>
-
 #include "installDebThread.h"
 
+#include <QDebug>
+#include <QVersionNumber>
+
 static const QString kParamInstallWine = "install_wine";
 static const QString kParamInstallConfig = "install_config";
 static const QString kParamInstallComaptible = "install_compatible";
+static const QString kParamInstallImmutable = "install_immutable";
+static const QString kParamInstallUab = "uab";
 
+static const QString kAptBin = "apt";
+static const QString kInstall = "install";
+static const QString kRemove = "remove";
+
+// for compatible mode
 static const QString kCompatibleBin = "deepin-compatible-ctl";
+static const QString kCompCheck = "check";
 static const QString kCompApp = "app";
-static const QString kCompInstall = "install";
-static const QString kCompRemove = "remove";
 static const QString kCompRootfs = "rootfs";
+static const QString kCompRootfsName = "--name";
+static const QString kCompJsonFormat = "--json";
+// current user(non root)
+static const QString kCompUser = "user";
+
+// for disable DebConf
+static const QString kDebConfEnv = "DEBIAN_FRONTEND";
+static const QString kDebConfDisable = "noninteractive";
 
 InstallDebThread::InstallDebThread()
 {
@@ -27,6 +42,7 @@ InstallDebThread::InstallDebThread()
 
     connect(m_proc, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(onFinished(int, QProcess::ExitStatus)));
     connect(m_proc, SIGNAL(readyReadStandardOutput()), this, SLOT(onReadoutput()));
+    connect(m_proc, &KProcess::readyReadStandardError, this, [this]() { qWarning() << m_proc->readAllStandardError(); });
 }
 
 InstallDebThread::~InstallDebThread()
@@ -41,18 +57,23 @@ void InstallDebThread::setParam(const QStringList &arguments)
         return;
     }
 
-    // normal command;
+    // normal command
     static QMap<QString, Command> kParamMap{{kParamInstallWine, InstallWine},
                                             {kParamInstallConfig, InstallConfig},
                                             {kParamInstallComaptible, Compatible},
-                                            {kCompInstall, Install},
-                                            {kCompRemove, Remove}};
+                                            {kParamInstallImmutable, Immutable},
+                                            {kParamInstallUab, LinglongUab},
+                                            {kInstall, Install},
+                                            {kRemove, Remove},
+                                            {kCompCheck, AppCheck}};
 
     for (auto itr = kParamMap.begin(); itr != kParamMap.end(); ++itr) {
         m_parser.addOption(QCommandLineOption(itr.key()));
     }
     QCommandLineOption rootfsOpt(kCompRootfs, "", "rootfsname");
     m_parser.addOption(rootfsOpt);
+    QCommandLineOption userOpt(kCompUser, "", "current user");
+    m_parser.addOption(userOpt);
 
     m_parser.process(arguments);
 
@@ -64,6 +85,9 @@ void InstallDebThread::setParam(const QStringList &arguments)
     if (m_parser.isSet(rootfsOpt)) {
         m_rootfs = m_parser.value(rootfsOpt);
     }
+    if (m_parser.isSet(userOpt)) {
+        m_user = m_parser.value(userOpt);
+    }
 
     m_listParam = m_parser.positionalArguments();
 }
@@ -132,8 +156,13 @@ void InstallDebThread::run()
         installWine();
     } else if (m_cmds.testFlag(Compatible)) {
         compatibleProcess();
+    } else if (m_cmds.testFlag(Immutable)) {
+        immutableProcess();
     } else if (m_cmds.testFlag(InstallConfig)) {
+        // InstallConfig must last, Compatible and Immutable maybe set InstallConfig too.
         installConfig();
+    } else if (m_cmds.testFlag(LinglongUab)) {
+        uabProcessCli();
     }
 }
 
@@ -146,11 +175,13 @@ void InstallDebThread::installWine()
         return;
     }
 
+    // Note: Notify the front-end installation to start, don't remove it.
+    qInfo() << "StartInstallDeepinwine";
+
+    // On immutable system: --fix-missing not support, apt command will transport to deepin-immutable-ctl
+    system("echo 'libpam-runtime libpam-runtime/override boolean false' | debconf-set-selections");
     system("echo 'libc6 libraries/restart-without-asking boolean true' | sudo debconf-set-selections\n");
-    m_proc->setProgram("sudo",
-                       QStringList() << "apt-get"
-                                     << "install" << m_listParam << "--fix-missing"
-                                     << "-y");
+    m_proc->setProgram("apt-get", QStringList() << "install" << m_listParam << "-y");
     m_proc->start();
     m_proc->waitForFinished(-1);
     m_proc->close();
@@ -180,8 +211,6 @@ void InstallDebThread::installConfig()
 
         getDescription(debPath);
 
-        // m_proc->start("sudo", QStringList() << "-S" <<  "dpkg-preconfigure" << "-f" << "Teletype" << m_listParam[1]);
-        //                m_proc->start("sudo", QStringList() << "-S" <<  "dpkg" << "-i" << debPath);
         m_proc->setProgram("sudo",
                            QStringList() << "-S"
                                          << "dpkg"
@@ -210,7 +239,6 @@ void InstallDebThread::compatibleProcess()
     QStringList params;
 
     if (m_cmds.testFlag(Install)) {
-        // e.g.: deepin-compatible app install [deb file]
         // only one package support
         QString debPath = m_listParam.first();
 
@@ -223,18 +251,29 @@ void InstallDebThread::compatibleProcess()
             getDescription(debPath);
         }
 
-        params << kCompApp << kCompInstall << debPath;
+        // e.g.: deepin-comptabile-ctl app --json install [deb file] [--name rootfsname]
+        params << kCompApp << kCompJsonFormat << kInstall << debPath;
 
     } else if (m_cmds.testFlag(Remove)) {
-        // e.g.: deepin-compatible app remove [package/name]
-        params << kCompApp << kCompRemove << m_listParam.first();
+        // e.g.: deepin-compatible-ctl app --json remove [package name]
+        params << kCompApp << kCompJsonFormat << kRemove << m_listParam.first();
+
+    } else if (m_cmds.testFlag(AppCheck)) {
+        // e.g.: deepin-compatible-ctl app --json check [package name]
+        params << kCompApp << kCompJsonFormat << kCompCheck << m_listParam.first();
 
     } else {
         return;
     }
 
     if (!m_rootfs.isEmpty()) {
-        params << QString("--%1").arg(kCompRootfs) << m_rootfs;
+        params << kCompRootfsName << m_rootfs;
+    }
+
+    if (!m_user.isEmpty()) {
+        auto env = QProcessEnvironment::systemEnvironment();
+        env.insert("SUDO_USER", m_user);
+        m_proc->setProcessEnvironment(env);
     }
 
     m_proc->setProgram(kCompatibleBin, params);
@@ -250,6 +289,125 @@ void InstallDebThread::compatibleProcess()
     }
 }
 
+bool newImmutableVersion() {
+    QProcess process;
+    process.start("dpkg-query", {"-W", "-f='${Version}'", "deepin-immutable-ctl"});
+    process.waitForFinished();
+    QString versionStr = process.readAllStandardOutput();
+
+    QVersionNumber version = QVersionNumber::fromString(versionStr.remove('\''));
+
+    return version >= QVersionNumber(0, 0, 28);
+}
+
+/**
+   @brief Install / remove package in immutable system.
+ */
+void InstallDebThread::immutableProcess()
+{
+    if (m_listParam.isEmpty()) {
+        return;
+    }
+    // for immutable system
+    static const QString kImmuEnvEnableWait = "DEEPIN_IMMUTABLE_CTL_WAIT_LOCK";
+    static const QString kImmuYes = "-y";
+    static const QString kImmuAllowDowngrades = "--allow-downgrades";
+
+    QStringList params;
+
+    if (m_cmds.testFlag(Install)) {
+        // e.g.: deepin-compatible app install [deb file]
+        // only one package support
+        QString debPath = m_listParam.first();
+
+        if (debPath.contains(" ") || debPath.contains("&") || debPath.contains(";") || debPath.contains("|") ||
+            debPath.contains("`")) {
+            debPath = SymbolicLink(debPath, "installPackage");
+        }
+
+        if (m_cmds.testFlag(InstallConfig)) {
+            getDescription(debPath);
+        } else {
+            // If current pacakge no DebConf config, disable DebConf
+            m_proc->setEnv(kDebConfEnv, kDebConfDisable);
+        }
+
+        // Note: deepin-immutable-ctl actually use apt to install/uninstall. (params transport to deepin-immutable-ctl)
+        // e.g.: apt install [deb file] -y (--allow-downgrades)
+        params << kInstall << debPath << kImmuYes;
+
+        // FIXME: temporary code, check if current Immutable System need --allow-downgrades
+        if (newImmutableVersion()) {
+            params << kImmuAllowDowngrades;
+        }
+
+    } else if (m_cmds.testFlag(Remove)) {
+        // e.g.: apt remove [package name] -y
+        params << kRemove << m_listParam.first() << kImmuYes;
+
+        // Disable DebConf while remove package
+        m_proc->setEnv(kDebConfEnv, kDebConfDisable);
+
+    } else {
+        return;
+    }
+
+    // enable wait another process release dpkg lock
+    m_proc->setEnv(kImmuEnvEnableWait, "1");
+    m_proc->setProgram(kAptBin, params);
+    qInfo() << "Exec:" << qPrintable(m_proc->program().join(' '));
+
+    m_proc->start();
+    m_proc->waitForFinished(-1);
+    m_proc->close();
+
+    QDir filePath(TEMPLATE_DIR);
+    if (filePath.exists()) {
+        filePath.removeRecursively();
+    }
+}
+
+/**
+   @brief Install / unisntall uab package in Linglong.
+
+   @todo Linglong's backend DBus interface is unstable, may change frequently in the near future.
+        We currently choose the cli interface, use the DBus interface in the future.
+ */
+void InstallDebThread::uabProcessCli()
+{
+    if (m_listParam.isEmpty()) {
+        return;
+    }
+    // The Linglong params
+    static const QString kUabBin = "ll-cli";
+    static const QString kUabInstall = "install";
+    static const QString kUabUninstall = "uninstall";
+    static const QString kUabJson = "--json";
+    static const QString kUabForce = "--force";  // Force install the application
+    static const QString kUabPass = "-y";        // Automatically answer yes to all questions
+
+    QStringList params;
+
+    if (m_cmds.testFlag(Install)) {
+        // e.g.: ll-cli install --json --force -y [uab file]
+        params << kUabInstall << kUabJson << kUabForce << kUabPass << m_listParam.first();
+
+    } else if (m_cmds.testFlag(Remove)) {
+        // e.g.: ll-cli uninstall --json [id/version]
+        params << kUabUninstall << kUabJson << m_listParam.first();
+
+    } else {
+        return;
+    }
+
+    m_proc->setProgram(kUabBin, params);
+    qInfo() << "Exec:" << qPrintable(m_proc->program().join(' '));
+
+    m_proc->start();
+    m_proc->waitForFinished(-1);
+    m_proc->close();
+}
+
 /**
  * @brief PackagesManager::SymbolicLink 创建软连接
  * @param previousName 原始路径
