@@ -14,6 +14,9 @@
 #include "view/widgets/error_notify_dialog_helper.h"
 #include "compatible/compatible_backend.h"
 #include "compatible/compatible_process_controller.h"
+#include "immutable/immutable_backend.h"
+#include "immutable/immutable_process_controller.h"
+#include "utils/qtcompat.h"
 
 #include <DDialog>
 #include <DSysInfo>
@@ -156,7 +159,7 @@ void DebListModel::initInstallConnections()
 
     // 配置安装结束
     connect(m_procInstallConfig,
-            static_cast<void (QProcess::*)(int)>(&QProcess::finished),
+            QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
             this,
             &DebListModel::slotConfigInstallFinish);
 
@@ -320,6 +323,11 @@ QVariant DebListModel::data(const QModelIndex &index, int role) const
             const QByteArray md5 = m_packagesManager->getPackageMd5(currentRow);
             return m_packagesManager->removePackages(md5);
         }
+
+        case PackageSharedPointerRole: {
+            return QVariant::fromValue(packagePtr(currentRow));
+        }
+
         case Qt::SizeHintRole:  // 设置当前index的大小
             return QSize(0, 48);
         case Qt::ToolTipRole:
@@ -409,6 +417,22 @@ bool DebListModel::slotUninstallPackage(int index)
         // otherwise uninstall from current system
     }
 
+    if (ImmBackend::instance()->immutableEnabled()) {
+        auto ptr = packagePtr(index);
+        if (ptr) {
+            if (uninstallImmutablePackage()) {
+                refreshOperatingPackageStatus(Pkg::PackageOperationStatus::Operating);
+                return true;
+            } else {
+                refreshOperatingPackageStatus(Pkg::PackageOperationStatus::Failed);
+                return false;
+            }
+        }
+
+        qWarning() << qPrintable("Trigger uninstall non-installed pacakge");
+        return false;
+    }
+
     DebFile debFile(m_packagesManager->package(m_operatingIndex));  // 获取到包
     if (!debFile.isValid())
         return false;
@@ -686,7 +710,20 @@ QString DebListModel::packageFailedReason(const int idx) const
     if (m_packagesManager->isArchError(idx))
         return tr("Unmatched package architecture");  // 判断是否架构冲突
 
-    switch (dependStatus.status) {
+    // need refactor, move to Deb::DebPackage
+    int status = dependStatus.status;
+    if (Pkg::CompatibleNotInstalled == status && CompBackend::instance()->supportAppCheck()) {
+        if (auto ptr = packagePtr(idx)) {
+            if (auto compPtr = ptr->compatible()) {
+                // back to depends break if no support rootfs on compatible mode.
+                if (compPtr->checked && compPtr->supportRootfs.isEmpty()) {
+                    status = Pkg::DependsBreak;
+                }
+            }
+        }
+    }
+
+    switch (status) {
         case Pkg::CompatibleIntalled:
             if (auto ptr = packagePtr(idx)) {
                 QString system = ptr->compatible()->rootfs;
@@ -892,10 +929,7 @@ void DebListModel::installDebs()
 
     Transaction *transaction = nullptr;
 
-    // reset package depends status
-    m_packagesManager->resetPackageDependsStatus(m_operatingStatusIndex);
-
-    // check available dependencies
+    // reset package depends status on installNextDeb(), check available dependencies
     const auto dependsStat = m_packagesManager->getPackageDependsStatus(m_operatingStatusIndex);
 
     // for compatbile install
@@ -905,7 +939,16 @@ void DebListModel::installDebs()
         } else {
             refreshOperatingPackageStatus(Pkg::Failed);
         }
+        return;
+    }
 
+    // for immutable system, if immutable is enabled, the normal installation process will not be entered
+    if (dependsStat.canInstall() && ImmBackend::instance()->immutableEnabled()) {
+        if (installImmutablePackage()) {
+            refreshOperatingPackageStatus(Pkg::Operating);
+        } else {
+            refreshOperatingPackageStatus(Pkg::Failed);
+        }
         return;
     }
 
@@ -1214,10 +1257,17 @@ void DebListModel::slotShowDevelopModeWindow()
     unlock->waitForFinished();
     auto output = unlock->readAllStandardOutput();
     auto str = QString::fromUtf8(output);
-    QRegExp re("\t.+\n");
+    REG_EXP re("\t.+\n");
     QString osVerStr;
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (re.indexIn(str) > -1) {
         auto result = re.cap(0);
+#else
+    QRegularExpressionMatch match = re.match(str);
+    if (match.hasMatch()) {
+        auto result = match.captured(0);
+#endif
         osVerStr = result.remove(0, 1).remove(result.size() - 1, 1);
         qInfo() << "lsb_release -r:" << output;
         qInfo() << "OS version:" << osVerStr;
@@ -1316,11 +1366,18 @@ bool DebListModel::checkDigitalSignature()
 
 void DebListModel::installNextDeb()
 {
-    m_packagesManager->resetPackageDependsStatus(m_operatingStatusIndex);  // 刷新软件包依赖状态
-    auto dependStatus = m_packagesManager->getPackageDependsStatus(m_operatingStatusIndex);
+    // If package is first package or install to compatible mode, not need reset status.
+    bool isFirstPackageAndCached = (0 == m_operatingStatusIndex) && m_packagesManager->cachedPackageDependStatus(m_operatingStatusIndex);
+    if (!isFirstPackageAndCached) {
+        // The apt backend cache may changed, refresh package status.
+        m_packagesManager->resetPackageDependsStatus(m_operatingStatusIndex);
+    }
+    PackageDependsStatus dependStatus = m_packagesManager->getPackageDependsStatus(m_operatingStatusIndex);
 
     if (dependStatus.canInstallCompatible() && supportCompatible()) {
         installDebs();
+    } else if (ImmBackend::instance()->immutableEnabled()) {
+        installDebs();
     } else if (dependStatus.isAvailable()) {  // 存在没有安装的依赖包，则进入普通安装流程执行依赖安装
         installDebs();
     } else if (dependStatus.status >= Pkg::DependsStatus::DependsBreak) {  // 安装前置条件不满足，无法处理
@@ -1527,6 +1584,11 @@ void DebListModel::slotConfigInputWrite(const QString &str)
         return;
     }
 
+    if (m_immProcessor && m_immProcessor->isRunning()) {
+        m_immProcessor->writeConfigData(str);
+        return;
+    }
+
     m_procInstallConfig->pty()->write(str.toUtf8());  // 将用户输入的配置项写入到配置安装进程中。
     m_procInstallConfig->pty()->write("\n");          // 写入换行，配置生效
 }
@@ -1697,7 +1759,10 @@ void DebListModel::ensureCompatibleProcessor()
         connect(
             m_compProcessor.data(), &Compatible::CompatibleProcessController::processOutput, this, [this](const QString &output) {
                 Q_EMIT signalAppendOutputInfo(output);
-                if (m_compProcessor->containTemplates()) {
+
+                if (configWindow->isVisible()) {
+                    configWindow->appendTextEdit(output);
+                } else if (m_compProcessor->needTemplates()) {
                     configWindow->appendTextEdit(output);
                     configWindow->show();
                 }
@@ -1764,6 +1829,84 @@ bool DebListModel::uninstallCompatiblePackage()
     return m_compProcessor->uninstall(m_currentPackage);
 }
 
+void DebListModel::ensureImmutableProcessor()
+{
+    if (!m_immProcessor) {
+        m_immProcessor.reset(new Immutable::ImmutableProcessController);
+
+        connect(
+            m_immProcessor.data(), &Immutable::ImmutableProcessController::processOutput, this, [this](const QString &output) {
+                Q_EMIT signalAppendOutputInfo(output);
+
+                if (configWindow->isVisible()) {
+                    configWindow->appendTextEdit(output);
+                } else if (m_immProcessor->needTemplates()) {
+                    configWindow->appendTextEdit(output);
+                    configWindow->show();
+                }
+            });
+
+        connect(m_immProcessor.data(), &Immutable::ImmutableProcessController::progressChanged, this, [this](float progress) {
+            const int progressValue =
+                static_cast<int>((100. / m_packagesManager->m_preparedPackages.size()) * (m_operatingIndex + progress / 100.));
+            Q_EMIT signalWholeProgressChanged(progressValue);
+
+            Q_EMIT signalCurrentPacakgeProgressChanged(static_cast<int>(progress));
+        });
+
+        connect(m_immProcessor.data(), &Immutable::ImmutableProcessController::processFinished, this, [this](bool success) {
+            if (configWindow->isVisible()) {
+                configWindow->hide();
+                configWindow->clearTexts();
+            }
+
+            if (success) {
+                refreshOperatingPackageStatus(Pkg::Success);
+            } else {
+                auto pkgPtr = m_immProcessor->currentPackage();
+                if (pkgPtr) {
+                    m_packageFailCode.insert(m_operatingPackageMd5, pkgPtr->errorCode());
+                    m_packageFailReason.insert(m_operatingPackageMd5, pkgPtr->errorString());
+
+                    if (Pkg::DigitalSignatureError == pkgPtr->errorCode()) {
+                        m_hierarchicalVerifyError = true;
+                    }
+
+                    if (Pkg::ConfigAuthCancel == pkgPtr->errorCode()) {
+                        // notify UI reset, cancel current flow
+                        m_workerStatus = WorkerPrepare;
+                        Q_EMIT signalAuthCancel();
+                        refreshOperatingPackageStatus(Pkg::Failed);
+                        return;
+                    }
+                }
+
+                refreshOperatingPackageStatus(Pkg::Failed);
+            }
+
+            bumpInstallIndex();
+        });
+    }
+}
+
+bool DebListModel::installImmutablePackage()
+{
+    ensureImmutableProcessor();
+
+    m_currentPackage = packagePtr(m_operatingIndex);
+
+    return m_immProcessor->install(m_currentPackage);
+}
+
+bool DebListModel::uninstallImmutablePackage()
+{
+    ensureImmutableProcessor();
+
+    m_currentPackage = packagePtr(m_operatingIndex);
+
+    return m_immProcessor->uninstall(m_currentPackage);
+}
+
 Deb::DebPackage::Ptr DebListModel::packagePtr(int index) const
 {
     Deb::DebPackage::Ptr pkgPtr;
