@@ -3,6 +3,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "utils.h"
+#include "qtcompat.h"
 
 #include <mutex>
 
@@ -35,6 +36,8 @@
 
 #include <QApt/Package>
 
+DWIDGET_USE_NAMESPACE
+
 QHash<QString, QPixmap> Utils::m_imgCacheHash;
 QHash<QString, QString> Utils::m_fontNameCache;
 
@@ -55,7 +58,7 @@ QFont Utils::loadFontBySizeAndWeight(const QString &fontFamily, int fontSize, in
     Q_UNUSED(fontSize)
 
     QFont font(fontFamily);
-    font.setWeight(fontWeight);
+    font.setWeight((QFont::Weight)fontWeight);
 
     return font;
 }
@@ -107,7 +110,7 @@ void Utils::bindFontBySizeAndWeight(QWidget *widget, const QString &fontFamily,
 
 QString Utils::fromSpecialEncoding(const QString &inputStr)
 {
-    bool bFlag = inputStr.contains(QRegExp("[\\x4e00-\\x9fa5]+"));
+    bool bFlag = inputStr.contains(REG_EXP("[\\x4e00-\\x9fa5]+"));
     if (bFlag) {
         return inputStr;
     }
@@ -179,7 +182,7 @@ Utils::VerifyResultCode Utils::Digital_Verify(const QString &filepath_name)
 
 QString Utils::holdTextInRect(const QFont &font, const QString &srcText, const QSize &size)
 {
-    bool bContainsChinese = srcText.contains(QRegExp("[\\x4e00-\\x9fa5]+"));
+    bool bContainsChinese = srcText.contains(REG_EXP("[\\x4e00-\\x9fa5]+"));
 
     QString text;
     QString tempText;
@@ -244,7 +247,7 @@ QString Utils::holdTextInRect(const QFont &font, const QString &srcText, const Q
 
 QString Utils::holdTextInRect(const QFont &font, const QString &srcText, const int &width)
 {
-    bool bContainsChinese = srcText.contains(QRegExp("[\\x4e00-\\x9fa5]+"));
+    bool bContainsChinese = srcText.contains(REG_EXP("[\\x4e00-\\x9fa5]+"));
 
     QString text;
     QString tempText;
@@ -307,9 +310,11 @@ Pkg::PackageReadability Utils::checkPackageReadable(const QString &packagePath)
     // Determine whether the route information is a local path
     QStorageInfo info(packagePath);
     QString device = info.device();
+    QString fsType = info.fileSystemType();
     // Blacklist identifies, gvfs/cifs as the file system
     // that currently manages the remote directory
-    if (device.startsWith("gvfs") || device.startsWith("cifs")) {
+    if (fsType.startsWith("gvfs") || fsType.startsWith("cifs")
+        || device.startsWith("gvfs") || device.startsWith("cifs")) {
         qWarning() << "Disable open remote file, the devices is" << device;
         return Pkg::PkgNotInLocal;
     }
@@ -365,7 +370,7 @@ QIcon Utils::packageIcon(Pkg::PackageType type)
 {
     if (Pkg::Uab == type) {
         // linglong uab package
-        static QIcon kUabIcon = QIcon::fromTheme("application-x-uab");
+        static QIcon kUabIcon = QIcon::fromTheme("application/x-executable");
         if (kUabIcon.isNull()) {
             // using DDciIcon to support new svg version (dsvg use librsvg backend)
             Dtk::Gui::DDciIcon dciIcon(QString(":/icons/deepin/uab/uos-application-bundle.dci"));
@@ -515,6 +520,32 @@ QString Utils::formatWrapText(const QString &text, int textWidth)
     return tipsText;
 }
 
+/**
+ * @return parse app black list from config file.
+ */
+QStringList Utils::parseBlackList()
+{
+    static const QString kBlackFileV20 {"/usr/share/udcp/appblacklist.txt"};
+    static const QString kBlackFileV25 {"/var/lib/udcp/appblacklist.txt"};
+    static const int kV25Version = 25;
+
+    const int sysVersion = Dtk::Core::DSysInfo::majorVersion().toInt();
+    QString blackFile = (sysVersion >= kV25Version) ? kBlackFileV25 : kBlackFileV20;
+    QFile blackListFile(blackFile);
+
+    if (blackListFile.exists()) {
+        blackListFile.open(QFile::ReadOnly);
+        QString blackApplications = blackListFile.readAll();
+        blackApplications.replace(" ", "");
+        blackApplications = blackApplications.replace("\n", "");
+        blackListFile.close();
+        return blackApplications.split(",");
+    }
+
+    qInfo() << "Black File not Found, " << blackFile;
+    return {};
+}
+
 /**
  * @brief Mark whether the wine pre-dependency is being installed.
  *        Not thread-safe.
